@@ -2,7 +2,7 @@ from notecoin.huobi.client import GenericClient, MarketClient
 from notecoin.huobi.dataset.core import *
 from notetool.tool.secret import read_secret
 from tqdm import tqdm
-
+import time
 
 class TradeUpdate:
     def __init__(self, db_path='/root/workspace/tmp/coin/huobi.db'):
@@ -105,6 +105,7 @@ class TradeUpdate:
                     self.insert_trade(symbol)
                 if kline:
                     self.insert_kline(symbol)
+                time.sleep(0.3)
             except Exception as e:
                 print(e)
 
